import React, { useState, useRef, useEffect } from 'react';
import { Link, NavLink, useNavigate, useLocation } from 'react-router-dom';
import { useAuth } from '../../contexts/AuthContext';
import { useProfileActions } from '../../contexts/ProfileActionsContext';
import { getFileUrl } from '../../services/pocketbaseService';
import { FaUserCircle, FaSignOutAlt, FaEdit, FaBars, FaTimes, FaTachometerAlt, FaBook, FaTrophy, FaCog, FaHeadset, FaHome, FaUser } from 'react-icons/fa'; // Import FaBook, FaTrophy, FaCog, and FaHeadset
import { FiSearch } from 'react-icons/fi';
import SearchBar from '../ui/SearchBar';
import AlphaBadge from '../ui/AlphaBadge';
import localLogo from '/logo.png';
import { canManageSystem } from '../../utils/permissions';
import Dock from '../reactbits/Components/Dock/Dock';
import '../reactbits/Components/Dock/Dock.css';
import { AnimatePresence, motion } from 'framer-motion';

const Header = () => {
  const { user, userProfile, signOut } = useAuth();
  const profileActions = useProfileActions();
  const navigate = useNavigate();
  const location = useLocation();
  const [isProfileMenuOpen, setIsProfileMenuOpen] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenu] = useState(false);
  const [isSearchOpen, setIsSearchOpen] = useState(false);
  const [logoSrc, setLogoSrc] = useState(localLogo);
  const profileMenuRef = useRef(null);
  const mobileMenuRef = useRef(null);
  const searchContainerRef = useRef(null); // Ref for the search dropdown container

  // Эффект для проверки доступности локального логотипа при монтировании
  useEffect(() => {
    const img = new Image();
    img.onload = () => setLogoSrc(localLogo); // Если локальный загрузился, используем его
    img.onerror = () => setLogoSrc('https://campfiregg.ru/logo.png'); // Если локальный не загрузился, пробуем внешний
    img.src = localLogo;
  }, []); // Запускаем только один раз при монтировании

  const handleExternalLogoError = () => {
    console.log("External logo failed to load.");
  };

  const toggleProfileMenu = () => {
    setIsProfileMenuOpen(!isProfileMenuOpen);
    setIsMobileMenu(false); // Close mobile menu if profile opens
    setIsSearchOpen(false); // Close search if profile opens
  };

  const toggleMobileMenu = () => {
    setIsMobileMenu(!isMobileMenuOpen);
    setIsProfileMenuOpen(false); // Close profile menu if mobile opens
    setIsSearchOpen(false); // Close search if mobile opens
  };

  const toggleSearch = () => {
    setIsSearchOpen(!isSearchOpen);
    setIsProfileMenuOpen(false); // Close other menus
    setIsMobileMenu(false); // Close other menus
  };

  const closeMenus = () => {
    setIsProfileMenuOpen(false);
    setIsMobileMenu(false);
    // Keep search open if it was opened via its own button, close only if clicking outside
  };

  const closeSearch = () => {
      setIsSearchOpen(false);
  };

  // Close menus/search when clicking outside
  useEffect(() => {
    const handleClickOutside = (event) => {
      if (profileMenuRef.current && !profileMenuRef.current.contains(event.target)) {
        setIsProfileMenuOpen(false);
      }
      if (mobileMenuRef.current && !mobileMenuRef.current.contains(event.target)) {
         setIsMobileMenu(false);
      }
       // Close search only if clicking outside the search container itself
       if (searchContainerRef.current && !searchContainerRef.current.contains(event.target)) {
           // Check if the click was NOT on the search toggle button
           const searchButton = document.getElementById('search-toggle-button');
           if (searchButton && searchButton !== event.target && !searchButton.contains(event.target)) {
               setIsSearchOpen(false);
           }
       }
    };

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);

  // Handle Edit Profile click from Header
  const handleEditProfileClick = () => {
      if (userProfile) {
          console.log('Header: Edit Profile clicked. Navigating to profile and triggering modal.');
          navigate(`/profile/${userProfile.username}`);
          if (profileActions?.triggerEditModal) {
              profileActions.triggerEditModal();
          }
          closeMenus();
      } else {
          console.log('Header: Edit Profile clicked, but userProfile is not available.');
      }
  };

  const canAccessAdmin = canManageSystem(user);

  const mainItems = [
    {
      icon: <FaHome className="w-5 h-5 text-campfire-light" />,
      label: 'Главная',
      onClick: () => navigate('/'),
      className: location.pathname === '/' ? 'bg-campfire-amber/20' : ''
    },
    {
      icon: <FaBook className="w-5 h-5 text-campfire-light" />,
      label: 'Каталог',
      onClick: () => navigate('/catalog'),
      className: location.pathname === '/catalog' ? 'bg-campfire-amber/20' : ''
    },
    {
      icon: <FaTrophy className="w-5 h-5 text-campfire-light" />,
      label: 'Рейтинги',
      onClick: () => navigate('/rating'),
      className: location.pathname === '/rating' ? 'bg-campfire-amber/20' : ''
    },
    {
      icon: <FiSearch className="w-5 h-5 text-campfire-light" />,
      label: 'Поиск',
      onClick: toggleSearch,
      className: isSearchOpen ? 'bg-campfire-amber/20' : ''
    }
  ];

  const profileItems = [
    {
      icon: (
        <div className="flex items-center gap-2 px-2">
          <img
            src={userProfile?.profile_picture ? getFileUrl(userProfile, 'profile_picture') : 'https://pocketbase.campfiregg.ru/api/files/_pb_users_auth_/g520s25pzm0t6e1/photo_2025_05_17_22_26_21_g2bi9umsuu.jpg'}
            alt={userProfile?.username || 'User'}
            className="w-6 h-6 rounded-full object-cover border border-campfire-ash/30"
          />
          <span className="text-[10px] text-campfire-light truncate max-w-[60px]">{userProfile?.username || 'Профиль'}</span>
        </div>
      ),
      onClick: () => navigate(userProfile ? `/profile/${userProfile.username}` : '/auth/login'),
      className: location.pathname.startsWith('/profile') ? 'bg-campfire-amber/20' : '',
      showLabel: false,
      isRectangular: true
    },
    {
      icon: <FaBars className="w-5 h-5 text-campfire-light" />,
      label: 'Меню',
      onClick: toggleProfileMenu,
      className: isProfileMenuOpen ? 'bg-campfire-amber/20' : ''
    }
  ];

  return (
		<>
      <header className="fixed top-2 left-0 right-0 z-50">
        <div className="bg-campfire-charcoal/80 backdrop-blur-md border-b border-campfire-ash/20 rounded-t-lg">
          <div className="container-custom flex items-center justify-between h-16 px-4">
            {/* Logo */}
            <Link to="/" className="flex items-center space-x-2">
          <img
                src={logoSrc}
                alt="CampFire мнение"
                className="h-12"
                onError={handleExternalLogoError}
              />
        </Link>

            {/* Main Dock Navigation */}
            <div className="hidden md:flex flex-1 justify-center">
              <div className="flex items-center gap-4">
                <Dock
                  items={mainItems}
                  className="bg-campfire-charcoal/50 backdrop-blur-sm"
                  distance={120}
                  panelHeight={50}
                  baseItemSize={32}
                  dockHeight={30}
                  magnification={40}
                  spring={{ mass: 0.2, stiffness: 200, damping: 15 }}
                />

                {/* Search Dock */}
                <AnimatePresence>
                  {isSearchOpen && (
                    <motion.div
                      initial={{ opacity: 0, width: 0 }}
                      animate={{ opacity: 1, width: '300px' }}
                      exit={{ opacity: 0, width: 0 }}
                      transition={{ duration: 0.2 }}
                      className="rounded-md overflow-hidden"
                    >
                      <div className="px-4 py-2">
                        <SearchBar onClose={closeSearch} />
                      </div>
                    </motion.div>
                  )}
                </AnimatePresence>
              </div>
            </div>

            {/* Profile Dock */}
            <div className="hidden md:flex relative">
              <Dock
                items={profileItems}
                className="bg-campfire-charcoal/50 backdrop-blur-sm"
                distance={120}
                panelHeight={50}
                baseItemSize={32}
                dockHeight={30}
                magnification={40}
                spring={{ mass: 0.2, stiffness: 200, damping: 15 }}
              />

              {/* Profile Dropdown Menu */}
              <AnimatePresence>
              {isProfileMenuOpen && (
                  <motion.div
                    initial={{ opacity: 0, y: -10 }}
                    animate={{ opacity: 1, y: 0 }}
                    exit={{ opacity: 0, y: -10 }}
                    transition={{ duration: 0.2 }}
                    className="absolute right-0 top-full mt-2 w-48 bg-campfire-charcoal rounded-md shadow-lg py-1 z-50 border border-campfire-ash/30"
                  >
                  <Link
                    to={`/profile/${userProfile?.username}`}
                    onClick={closeMenus}
                    className="block px-4 py-2 text-sm text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                  >
                    <FaUserCircle />
                    <span>Мой профиль</span>
                  </Link>
                    {canAccessAdmin && (
                       <Link
                           to="/admin"
                           onClick={closeMenus}
                           className="block px-4 py-2 text-sm text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                       >
                           <FaTachometerAlt />
                           <span>Админ панель</span>
                       </Link>
                   )}
                   {userProfile && (
                       <button
                           onClick={handleEditProfileClick}
                           className="block w-full text-left px-4 py-2 text-sm text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                       >
                           <FaEdit />
                           <span>Редактировать профиль</span>
                       </button>
                   )}
                    {user && (
                      <>
                        <Link
                          to="/support"
                          className="block px-4 py-2 text-sm text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                        >
                          <FaHeadset />
                          <span>Поддержка</span>
                        </Link>
                  <button
                    onClick={() => {
                      signOut();
                      closeMenus();
                    }}
                    className="block w-full text-left px-4 py-2 text-sm text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                  >
                    <FaSignOutAlt />
                    <span>Выйти</span>
                  </button>
                      </>
                    )}
                  </motion.div>
              )}
              </AnimatePresence>
            </div>

          {/* Mobile Menu Button */}
          <div className="md:hidden">
            <button onClick={toggleMobileMenu} className="text-campfire-light focus:outline-none">
              {isMobileMenuOpen ? <FaTimes size={24} /> : <FaBars size={24} />}
            </button>
          </div>
        </div>
      </div>

        {/* Search Results Dropdown */}
        <AnimatePresence>
          {isSearchOpen && (
            <motion.div
              initial={{ opacity: 0, height: 0 }}
              animate={{ opacity: 1, height: 'auto' }}
              exit={{ opacity: 0, height: 0 }}
              transition={{ duration: 0.2 }}
              className="bg-campfire-charcoal shadow-lg border-b border-campfire-ash/30 overflow-hidden"
            >
              <div className="container-custom mx-auto px-4 py-4">
                {/* Здесь будет компонент с результатами поиска */}
              </div>
            </motion.div>
          )}
        </AnimatePresence>

        {/* Mobile Menu */}
        <AnimatePresence>
          {isMobileMenuOpen && (
            <motion.nav
              initial={{ opacity: 0, height: 0 }}
              animate={{ opacity: 1, height: 'auto' }}
              exit={{ opacity: 0, height: 0 }}
              transition={{ duration: 0.2 }}
              ref={mobileMenuRef}
              className="md:hidden bg-campfire-charcoal border-t border-campfire-ash/20"
                 >
              <div className="container-custom py-4 px-4">
            <NavLink
              to="/catalog"
              onClick={closeMenus}
              className={({ isActive }) =>
                    `block px-4 py-2 hover:bg-campfire-ash/20 transition-colors ${isActive ? 'text-campfire-amber' : 'text-campfire-light'} flex items-center space-x-2`
              }
            >
                  <FaBook size={20} />
                  <span>Каталог</span>
            </NavLink>
             <NavLink
              to="/rating"
              onClick={closeMenus}
              className={({ isActive }) =>
                    `block px-4 py-2 hover:bg-campfire-ash/20 transition-colors ${isActive ? 'text-campfire-amber' : 'text-campfire-light'} flex items-center space-x-2`
              }
            >
                  <FaTrophy size={20} />
                  <span>Рейтинги</span>
            </NavLink>
             {user && (
                 <button
                     onClick={() => {
                         signOut();
                         closeMenus();
                     }}
                     className="block w-full text-left px-4 py-2 text-campfire-light hover:bg-campfire-ash/20 flex items-center space-x-2"
                 >
                     <FaSignOutAlt />
                     <span>Выйти</span>
                 </button>
             )}
          </div>
            </motion.nav>
      )}
        </AnimatePresence>
    </header>

      {/* Мобильный Dock */}
      <motion.div
        initial={{ y: 100, opacity: 0 }}
        animate={{ y: 0, opacity: 1 }}
        exit={{ y: 100, opacity: 0 }}
        transition={{ duration: 0.3 }}
        className="md:hidden fixed bottom-0 left-0 right-0 z-50 bg-campfire-charcoal/80 backdrop-blur-md border-t border-campfire-ash/20"
      >
        <div className="container-custom py-2">
          <Dock
            items={mainItems}
            className="bg-campfire-charcoal/50 backdrop-blur-sm rounded-md"
            distance={120}
            panelHeight={50}
            baseItemSize={32}
            dockHeight={30}
            magnification={40}
            spring={{ mass: 0.2, stiffness: 200, damping: 15 }}
          />
        </div>
      </motion.div>

      {/* Alpha Badge */}
      <AlphaBadge />
			</>
  );
};

export default Header;