import React, {
  createContext,
  useContext,
  useState,
  useEffect,
  useMemo,
} from "react";
import {
  pb, // Import PocketBase instance for authStore listener
  signUp as pbSignUp,
  signIn as pbSignIn,
  signOut as pbSignOut,
  getUserProfile,
  requestPasswordReset as pbRequestPasswordReset, // Import the new function
} from "../services/pocketbaseService"; // Use the new service file

const AuthContext = createContext();

export const useAuth = () => {
  // CORRECT: useContext is called at the top level of the useAuth hook function
  const context = useContext(AuthContext);
  if (!context) {
    // This error should ideally not happen if AuthProvider is used correctly
    // and handles its own initialization state before rendering children.
    console.error("useAuth must be used within an AuthProvider"); // Add error logging
    throw new Error("useAuth must be used within an AuthProvider");
  }
  return context;
};

export const AuthProvider = ({ children }) => {
  const [currentUser, setCurrentUser] = useState(null);
  const [userProfile, setUserProfile] = useState(null);
  const [loading, setLoading] = useState(true); // Start in loading state
  const [error, setError] = useState(null);
  const [isInitialized, setIsInitialized] = useState(false); // Track initialization

  console.log('AuthProvider: Component rendering. State:', { currentUser: !!currentUser, userProfile: !!userProfile, loading, error, isInitialized }); // Add logging

  // Function to load user profile (kept for potential manual refresh)
  const loadUserProfile = async (userId) => {
    if (!userId) {
      console.log('AuthProvider: loadUserProfile: Нет userId для загрузки профиля');
      return null;
    }

    try {
      console.log('AuthProvider: loadUserProfile: Загрузка профиля пользователя:', userId);
      // In PocketBase, the auth model *is* the user record, so we don't need a separate profile fetch
      // unless we need expanded relations not included in the auth model.
      // For now, we assume the auth model is sufficient for basic profile info.
      // If we needed expanded data, we'd use pb.collection('users').getOne(userId, { expand: '...' });
      const profile = await pb.collection('users').getOne(userId); // Fetch the full user record
      console.log('AuthProvider: loadUserProfile: Профиль загружен:', profile);
      return profile;

    } catch (error) {
      console.error('AuthProvider: loadUserProfile: Ошибка загрузки профиля:', error); // Add error logging
      // Don't set global error here, just log
      return null;
    }
  };

  useEffect(() => {
    let mounted = true;
    console.log('AuthProvider: useEffect: Инициализация PocketBase authStore listener...'); // Add logging

    // Use PocketBase's authStore.onChange listener
    // The 'true' argument runs the listener immediately on mount,
    // which is perfect for initial auth state check.
    const unsubscribe = pb.authStore.onChange(async (token, model) => {
      if (!mounted) {
        console.log('AuthProvider: authStore.onChange: Component unmounted, skipping state update.'); // Add logging
        return;
      }

      console.log('AuthProvider: authStore.onChange: Изменение состояния авторизации:', { token: !!token, model: !!model }); // Add logging

      // setLoading(true); // Avoid setting loading here to prevent flicker during state changes
      setError(null); // Clear previous errors

      try { // Wrap state update logic in try-catch
        if (model) { // model is the authenticated user record
          console.log('AuthProvider: authStore.onChange: Пользователь найден:', model.id); // Add logging
          setCurrentUser(model); // Set the user model directly
          // Fetch the full user record including any necessary expansions if the auth model is insufficient
          // For now, let's assume the auth model has basic profile fields like username, avatar, etc.
          // If you need expanded relations (like 'showcase'), you might need a separate fetch here
          // or ensure they are included in the auth model via PocketBase settings if possible.
          // For simplicity, let's just use the model as the profile for now.
          setUserProfile(model); // In PocketBase, model is the user record
          setError(null); // Clear error on successful user/profile load
        } else {
          console.log('AuthProvider: authStore.onChange: Пользователь не найден (вышел)'); // Add logging
          setCurrentUser(null);
          setUserProfile(null);
          setError(null); // Clear error when user logs out
        }
      } catch (err) {
         console.error('AuthProvider: authStore.onChange: Ошибка при обработке изменения состояния:', err); // Add error logging
         setError(err.message || 'Ошибка при обработке состояния авторизации');
         setCurrentUser(null);
         setUserProfile(null);
      } finally {
         // Always set initialized and loading=false after the first check runs
         // This ensures the provider is marked as ready after the initial auth state is determined.
         if (!isInitialized) { // Only set initialized once
            setIsInitialized(true);
            console.log('AuthProvider: authStore.onChange: Initialized set to true.'); // Add logging
         }
         setLoading(false); // Always set loading to false after processing the change
         console.log('AuthProvider: authStore.onChange: Обработка завершена. isInitialized:', isInitialized, 'loading:', loading); // Add logging
      }


    }, true); // The 'true' argument runs the listener immediately on mount

    return () => {
      console.log('AuthProvider: useEffect cleanup: Отписка от изменений состояния авторизации'); // Add logging
      mounted = false;
      unsubscribe(); // Unsubscribe from the listener
    };
  }, []); // Empty dependency array means this runs only once on mount

  // Manual profile refresh function (useful after profile updates)
  const refreshUserProfile = async () => {
    if (currentUser) {
      setLoading(true); // Indicate loading while refreshing profile
      try {
        console.log('AuthProvider: refreshUserProfile: Refreshing profile for user:', currentUser.id); // Add logging
        // Fetch the latest user record
        const profile = await pb.collection('users').getOne(currentUser.id);
        setUserProfile(profile);
        setError(null);
        console.log('AuthProvider: refreshUserProfile: Profile refreshed successfully.'); // Add logging
      } catch (err) {
        console.error('AuthProvider: Ошибка при обновлении профиля:', err); // Add error logging
        setError(err.message);
      } finally {
        setLoading(false);
        console.log('AuthProvider: refreshUserProfile: Refresh complete.'); // Add logging
      }
    } else {
       console.log('AuthProvider: refreshUserProfile: No current user to refresh profile.'); // Add logging
    }
  };


  const signIn = async (email, password) => {
    try {
      setLoading(true); // Set loading at the start of the async operation
      setError(null);
      console.log('AuthProvider: signIn: Попытка входа для', email); // Add logging
      const userRecord = await pbSignIn(email, password); // pbSignIn returns the record
      console.log('AuthProvider: signIn: Вход успешен', userRecord); // Add logging
      // authStore.onChange listener will handle setting currentUser and userProfile
      return userRecord;
    } catch (error) {
      console.error('AuthProvider: signIn: Ошибка входа:', error); // Add error logging
      setError(error.message);
      throw error;
    } finally {
      // Loading is handled by authStore.onChange after state update
      // However, if authStore.onChange doesn't fire (e.g., invalid credentials),
      // we need to ensure loading is set to false here.
      // Let's add a small delay or check authStore state to avoid race conditions
      // with the authStore.onChange listener. A simple finally block might conflict.
      // A better approach is to rely solely on authStore.onChange for loading state
      // after the initial check, but ensure errors are caught and displayed.
      // For now, let's ensure error is set and the UI reacts to it.
      // setLoading(false); // Removed to rely on authStore.onChange
      console.log('AuthProvider: signIn: Operation finished.'); // Add logging
    }
  };

  const signUp = async (email, password, username) => {
    try {
      setLoading(true); // Set loading at the start of the async operation
      setError(null);
      console.log('AuthProvider: signUp: Попытка регистрации для', email); // Add logging
      const { user, profile } = await pbSignUp(email, password, username); // pbSignUp returns user and profile
      console.log('AuthProvider: signUp: Регистрация успешна', { user, profile }); // Add logging
      // authStore.onChange listener will handle setting currentUser and userProfile
      return { user, profile };
    } catch (error) {
      console.error('AuthProvider: signUp: Ошибка регистрации:', error); // Add error logging
      setError(error.message);
      throw error;
    } finally {
      // Loading is handled by authStore.onChange after state update
      // setLoading(false); // Removed to rely on authStore.onChange
      console.log('AuthProvider: signUp: Operation finished.'); // Add logging
    }
  };

  const signOut = async () => {
    try {
      setLoading(true); // Set loading at the start of the async operation
      setError(null);
      console.log('AuthProvider: signOut: Попытка выхода'); // Add logging
      await pbSignOut();
      console.log('AuthProvider: signOut: Выход успешен'); // Add logging
      // authStore.onChange listener will handle setting currentUser and userProfile
    } catch (error) {
      console.error('AuthProvider: signOut: Ошибка выхода:', error); // Add error logging
      setError(error.message);
      throw error;
    } finally {
      // Loading is handled by authStore.onChange after state update
      // setLoading(false); // Removed to rely on authStore.onChange
      console.log('AuthProvider: signOut: Operation finished.'); // Add logging
    }
  };

  // New function for password reset request
  const requestPasswordReset = async (email) => {
    try {
      setLoading(true);
      setError(null);
      console.log('AuthProvider: requestPasswordReset: Попытка сброса пароля для', email); // Add logging
      await pbRequestPasswordReset(email);
      console.log('AuthProvider: requestPasswordReset: Запрос на сброс пароля отправлен'); // Add logging
      return true; // Indicate success
    } catch (error) {
      console.error('AuthProvider: requestPasswordReset: Ошибка при запросе сброса пароля:', error); // Add error logging
      setError(error.message);
      throw error;
    } finally {
      setLoading(false);
      console.log('AuthProvider: requestPasswordReset: Operation finished.'); // Add logging
    }
  };


  // Use useMemo for context value
  const value = useMemo(() => ({
    user: currentUser, // This is the PocketBase user record
    userProfile, // This is the same as user in PocketBase context
    loading,
    error,
    signIn, // Include signIn in the context value
    signUp,
    signOut,
    isInitialized,
    refreshUserProfile, // Add refresh function to context
    requestPasswordReset, // Add password reset function
  }), [currentUser, userProfile, loading, error, isInitialized, signIn, signUp, signOut, refreshUserProfile, requestPasswordReset]); // Add functions to dependency array

  console.log('AuthProvider: Rendering with value:', { user: !!value.user, userProfile: !!value.userProfile, loading: value.loading, error: !!value.error, isInitialized: value.isInitialized }); // Add logging

  // Render loading or error state until initialized
  // Removed the error display block here to rely on pages displaying errors from context
  // We still show a loading spinner if not initialized or loading
  if (loading || !isInitialized) {
     console.log('AuthProvider: Рендеринг состояния загрузки/инициализации...'); // Add logging
     return (
        <div className="min-h-screen flex items-center justify-center bg-campfire-dark">
           <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
        </div>
     );
  }


  // Render children only when initialized and loading is false
  console.log('AuthProvider: Инициализация завершена. Рендеринг детей.'); // Add logging
  return (
    <AuthContext.Provider value={value}>
      {children}
    </AuthContext.Provider>
  );
};
